@@ -42,6 +42,10 @@
 
 #include "nmdebug.h"
 
+#include <QDBusMetaType>
+#include <QDBusReply>
+#include <QTimer>
+
 #define DBUS_OBJECT_MANAGER "org.freedesktop.DBus.ObjectManager"
 #define DBUS_PROPERTIES "org.freedesktop.DBus.Properties"
 
@@ -1161,3 +1165,6 @@ NetworkManager::Notifier *NetworkManager::notifier()
 {
     return globalNetworkManager;
 }
+
+#include "moc_manager.cpp"
+#include "moc_manager_p.cpp"
